@@ -29,8 +29,10 @@ from lutris.util.log import logger
     COL_LASTPLAYED_TEXT,
     COL_INSTALLED,
     COL_INSTALLED_AT,
-    COL_INSTALLED_AT_TEXT
-) = list(range(13))
+    COL_INSTALLED_AT_TEXT,
+    COL_PLAYTIME,
+    COL_PLAYTIME_TEXT
+) = list(range(15))
 
 COLUMN_NAMES = {
     COL_NAME: 'name',
@@ -38,7 +40,8 @@ COLUMN_NAMES = {
     COL_RUNNER_HUMAN_NAME: 'runner',
     COL_PLATFORM: 'platform',
     COL_LASTPLAYED_TEXT: 'lastplayed',
-    COL_INSTALLED_AT_TEXT: 'installed_at'
+    COL_INSTALLED_AT_TEXT: 'installed_at',
+    COL_PLAYTIME_TEXT: 'playtime'
 }
 
 
@@ -59,7 +62,7 @@ class GameStore(GObject.Object):
         self.modelfilter = None
         self.runner_names = {}
 
-        self.store = Gtk.ListStore(int, str, str, Pixbuf, str, str, str, str, int, str, bool, int, str)
+        self.store = Gtk.ListStore(int, str, str, Pixbuf, str, str, str, str, int, str, bool, int, str, str, str)
         if show_installed_first:
             self.store.set_sort_column_id(COL_INSTALLED, Gtk.SortType.DESCENDING)
         else:
@@ -176,6 +179,9 @@ class GameStore(GObject.Object):
 
         pixbuf = get_pixbuf_for_game(game['slug'], self.icon_type,
                                      game['installed'])
+        playtime_text = ''
+        if game['playtime']:
+            playtime_text = game['playtime']
         self.store.append((
             game['id'],
             game['slug'],
@@ -189,7 +195,9 @@ class GameStore(GObject.Object):
             lastplayed_text,
             game['installed'],
             game['installed_at'],
-            installed_at_text
+            installed_at_text,
+            game['playtime'],
+            playtime_text
         ))
         self.sort_view(self.show_installed_first)
 
@@ -203,7 +211,7 @@ class GameStore(GObject.Object):
             self.emit('icons-changed', icon_type)  # Obsolete, only for GridView
 
 
-class GameView(object):
+class GameView:
     __gsignals__ = {
         "game-selected": (GObject.SIGNAL_RUN_FIRST, None, ()),
         "game-activated": (GObject.SIGNAL_RUN_FIRST, None, ()),
@@ -282,6 +290,7 @@ class GameView(object):
         row = self.get_row_by_id(game['id'])
         if row:
             row[COL_YEAR] = str(game['year'])
+            row[COL_PLAYTIME_TEXT] = game['playtime']
             self.update_image(game['id'], row[COL_INSTALLED])
 
     def update_image(self, game_id, is_installed=False):
@@ -295,7 +304,7 @@ class GameView(object):
                                               is_installed)
             row[COL_ICON] = game_pixbuf
             row[COL_INSTALLED] = is_installed
-            if type(self) is GameGridView:
+            if isinstance(self, GameGridView):
                 GLib.idle_add(self.queue_draw)
 
     def popup_contextual_menu(self, view, event):
@@ -305,9 +314,9 @@ class GameView(object):
         try:
             view.current_path = view.get_path_at_pos(event.x, event.y)
             if view.current_path:
-                if type(view) is GameGridView:
+                if isinstance(view, GameGridView):
                     view.select_path(view.current_path)
-                elif type(view) is GameListView:
+                elif isinstance(view, GameListView):
                     view.set_cursor(view.current_path[0])
         except ValueError:
             (_, path) = view.get_selection().get_selected()
@@ -353,6 +362,7 @@ class GameListView(Gtk.TreeView, GameView):
         self.set_sort_with_column(COL_LASTPLAYED_TEXT, COL_LASTPLAYED)
         self.set_column(default_text_cell, "Installed at", COL_INSTALLED_AT_TEXT, 120)
         self.set_sort_with_column(COL_INSTALLED_AT_TEXT, COL_INSTALLED_AT)
+        self.set_column(default_text_cell, "Play Time", COL_PLAYTIME_TEXT, 100)
 
         self.get_selection().set_mode(Gtk.SelectionMode.SINGLE)
 
@@ -360,7 +370,8 @@ class GameListView(Gtk.TreeView, GameView):
         self.connect('row-activated', self.on_row_activated)
         self.get_selection().connect('changed', self.on_cursor_changed)
 
-    def set_text_cell(self):
+    @staticmethod
+    def set_text_cell():
         text_cell = Gtk.CellRendererText()
         text_cell.set_padding(10, 0)
         text_cell.set_property("ellipsize", Pango.EllipsizeMode.END)
@@ -393,10 +404,10 @@ class GameListView(Gtk.TreeView, GameView):
         """Return the currently selected game's id."""
         selection = self.get_selection()
         if not selection:
-            return
+            return None
         model, select_iter = selection.get_selected()
         if not select_iter:
-            return
+            return None
         return model.get_value(select_iter, COL_ID)
 
     def set_selected_game(self, game_id):
@@ -412,7 +423,8 @@ class GameListView(Gtk.TreeView, GameView):
         self.selected_game = self.get_selected_game()
         self.emit("game-activated")
 
-    def on_column_width_changed(self, col, *args):
+    @staticmethod
+    def on_column_width_changed(col, *args):
         col_name = col.get_title()
         if col_name:
             settings.write_setting(col_name.replace(' ', '') + '_column_width',
@@ -545,7 +557,7 @@ class ContextualMenu(Gtk.Menu):
             'browse': not is_installed or runner_slug == 'browser',
         }
         for menuitem in self.get_children():
-            if type(menuitem) is not Gtk.ImageMenuItem:
+            if not isinstance(menuitem, Gtk.ImageMenuItem):
                 continue
             action = menuitem.action_id
             visible = not hiding_condition.get(action)
