@@ -44,7 +44,7 @@ def get_runner_icon(runner_name, format='image', size=None):
                              runner_name + '.png')
     if not os.path.exists(icon_path):
         logger.error("Unable to find icon '%s'", icon_path)
-        return
+        return None
     if format == 'image':
         icon = Gtk.Image()
         icon.set_from_file(icon_path)
@@ -75,7 +75,7 @@ def get_pixbuf_for_game(game_slug, icon_type, is_installed=True):
         icon_path = datapath.get_icon_path(game_slug)
     else:
         logger.error("Invalid icon type '%s'", icon_type)
-        return
+        return None
 
     size = IMAGE_SIZES[icon_type]
 
@@ -86,5 +86,3 @@ def get_pixbuf_for_game(game_slug, icon_type, is_installed=True):
                          0, 0, 1, 1, GdkPixbuf.InterpType.NEAREST, 100)
         return transparent_pixbuf
     return pixbuf
-
-
