@@ -3,19 +3,20 @@
 import os
 import time
 import yaml
-import shutil
 
 from gi.repository import GLib
 
 from lutris import pga
 from lutris import settings
 from lutris.game import Game
+from lutris.gui.dialogs import WineNotInstalledWarning
 from lutris.util import system
 from lutris.util.strings import unpack_dependencies
 from lutris.util.jobs import AsyncCall
 from lutris.util.log import logger
 from lutris.util.steam import get_app_state_log
 from lutris.util.http import Request
+from lutris.util.wine import get_wine_version_exe, get_system_wine_version
 
 from lutris.config import LutrisConfig, make_game_config_id
 
@@ -45,8 +46,7 @@ def fetch_script(game_slug, revision=None):
 
     if key:
         return response[key]
-    else:
-        return response
+    return response
 
 
 def read_script(filename):
@@ -59,6 +59,7 @@ def read_script(filename):
         return scripts['results']
     return scripts
 
+
 def _get_game_launcher(script):
     """Return the key and value of the launcher"""
     launcher_value = None
@@ -66,7 +67,7 @@ def _get_game_launcher(script):
     # exe64 can be provided to specify an executable for 64bit systems
     exe = 'exe64' if 'exe64' in script and system.IS_64BIT else 'exe'
 
-    for launcher in [exe, 'iso', 'rom', 'disk', 'main_file']:
+    for launcher in (exe, 'iso', 'rom', 'disk', 'main_file'):
         if launcher not in script:
             continue
         launcher_value = script[launcher]
@@ -78,7 +79,7 @@ def _get_game_launcher(script):
 
     if not launcher_value:
         launcher = None
-    return (launcher, launcher_value)
+    return launcher, launcher_value
 
 
 class ScriptInterpreter(CommandsMixin):
@@ -192,7 +193,8 @@ class ScriptInterpreter(CommandsMixin):
             self.errors.append('Scripts can\'t have both extends and requires')
         return not bool(self.errors)
 
-    def _get_installed_dependency(self, dependency):
+    @staticmethod
+    def _get_installed_dependency(dependency):
         """Return whether a dependency is installed"""
         game = pga.get_game_by_field(dependency, field='installer_slug')
 
@@ -221,7 +223,7 @@ class ScriptInterpreter(CommandsMixin):
             else:
                 if not system.find_executable(dependency):
                     raise ScriptingError(
-                        "This installer requires %s on your system" % (dependency)
+                        "This installer requires %s on your system" % dependency
                     )
 
     def _check_dependency(self):
@@ -278,7 +280,6 @@ class ScriptInterpreter(CommandsMixin):
                     raise ScriptingError("Lutris does not have necessary permissions to install to choosen game dir:", self.target_path)
                 self.reversion_data['created_main_dir'] = True
 
-
         if len(self.game_files) < len(self.files):
             logger.info(
                 "Downloading file %d of %d",
@@ -381,9 +382,7 @@ class ScriptInterpreter(CommandsMixin):
             'file_id': file_id
         }
 
-        logger.debug(
-            "Getting Steam data for appid %s" % self.steam_data['appid']
-        )
+        logger.debug("Getting Steam data for appid %s", self.steam_data['appid'])
 
         self.parent.clean_widgets()
         self.parent.add_spinner()
@@ -432,6 +431,9 @@ class ScriptInterpreter(CommandsMixin):
                     params['fallback'] = False
             if not runner.is_installed(**params):
                 self.runners_to_install.append(runner)
+
+        if self.runner.startswith('wine') and not get_system_wine_version():
+            WineNotInstalledWarning(parent=self.parent)
         self.install_runners()
 
     def install_runners(self):
@@ -442,7 +444,7 @@ class ScriptInterpreter(CommandsMixin):
             self.install_runner(runner)
 
     def install_runner(self, runner):
-        logger.debug('Installing {}'.format(runner.name))
+        logger.debug('Installing %s', runner.name)
         try:
             runner.install(
                 version=self._get_runner_version(),
@@ -528,7 +530,8 @@ class ScriptInterpreter(CommandsMixin):
         else:
             self._finish_install()
 
-    def _get_command_name_and_params(self, command_data):
+    @staticmethod
+    def _get_command_name_and_params(command_data):
         if isinstance(command_data, dict):
             command_name = list(command_data.keys())[0]
             command_params = command_data[command_name]
@@ -554,6 +557,7 @@ class ScriptInterpreter(CommandsMixin):
 
     def _finish_install(self):
         game = self.script.get('game')
+        launcher_value = None
         if game:
             launcher, launcher_value = _get_game_launcher(game)
         path = None
@@ -564,8 +568,7 @@ class ScriptInterpreter(CommandsMixin):
 
         if path and not os.path.isfile(path):
             self.parent.set_status("Installation didn't complete successfully")
-            self.parent.on_install_error("Installation failed! Specified"
-            " executable not found.")
+            self.parent.on_install_error("Game executable not found in %s" % path)
         else:
             self.parent.set_status("Writing configuration")
             self._write_config()
@@ -626,7 +629,7 @@ class ScriptInterpreter(CommandsMixin):
         # script as a shortcut, this integrates them into the game config
         # properly
         launcher, launcher_value = _get_game_launcher(self.script)
-        if type(launcher_value) == list:
+        if isinstance(launcher_value, list):
             game_files = []
             for game_file in launcher_value:
                 if game_file in self.game_files:
@@ -639,9 +642,7 @@ class ScriptInterpreter(CommandsMixin):
                 launcher_value = (
                     self.game_files[launcher_value]
                 )
-            elif self.target_path and os.path.exists(
-                os.path.join(self.target_path, launcher_value)
-            ):
+            elif self.target_path and os.path.exists(os.path.join(self.target_path, launcher_value)):
                 launcher_value = os.path.join(self.target_path, launcher_value)
             config['game'][launcher] = launcher_value
 
@@ -667,9 +668,7 @@ class ScriptInterpreter(CommandsMixin):
             if isinstance(value, list):
                 config[key] = [self._substitute(i) for i in value]
             elif isinstance(value, dict):
-                config[key] = dict(
-                    [(k, self._substitute(v)) for (k, v) in value.items()]
-                )
+                config[key] = {k: self._substitute(v) for (k, v) in value.items()}
             elif isinstance(value, bool):
                 config[key] = value
             else:
@@ -682,8 +681,7 @@ class ScriptInterpreter(CommandsMixin):
 
     def cleanup(self):
         os.chdir(os.path.expanduser('~'))
-        if os.path.exists(self.cache_path):
-            shutil.rmtree(self.cache_path)
+        system.remove_folder(self.cache_path)
 
     # --------------
     # Revert install
@@ -697,8 +695,7 @@ class ScriptInterpreter(CommandsMixin):
             self.abort_current_task()
 
         if self.reversion_data.get('created_main_dir'):
-            if os.path.exists(self.target_path):
-                shutil.rmtree(self.target_path)
+            system.remove_folder(self.target_path)
 
     # -------------
     # Utility stuff
@@ -795,8 +792,7 @@ class ScriptInterpreter(CommandsMixin):
             logger.debug('Steam game has finished installing')
             self._on_steam_game_installed()
             return False
-        else:
-            return True
+        return True
 
     def _on_steam_game_installed(self, *args):
         """Fired whenever a Steam game has finished installing."""
@@ -833,5 +829,5 @@ class ScriptInterpreter(CommandsMixin):
 
     def eject_wine_disc(self):
         prefix = self.target_path
-        wine_path = wine.get_wine_version_exe(self._get_runner_version())
+        wine_path = get_wine_version_exe(self._get_runner_version())
         wine.eject_disc(wine_path, prefix)
