@@ -1,6 +1,5 @@
-import os
-
 from lutris.runners.runner import Runner
+from lutris.util import system
 
 
 class ags(Runner):
@@ -37,7 +36,7 @@ class ags(Runner):
         """Run the game."""
 
         main_file = self.game_config.get('main_file') or ''
-        if not os.path.exists(main_file):
+        if not system.path_exists(main_file):
             return {'error': 'FILE_NOT_FOUND', 'file': main_file}
 
         arguments = [self.get_executable()]
