@@ -1,6 +1,5 @@
-import os
-
 from lutris.runners.runner import Runner
+from lutris.util import system
 
 
 class desmume(Runner):
@@ -12,14 +11,14 @@ class desmume(Runner):
         'option': 'main_file',
         'type': 'file',
         'label': 'ROM file',
-        'help': ("The game data, commonly called a ROM image.")
+        'help': "The game data, commonly called a ROM image."
     }]
 
     def play(self):
         """Run the game."""
         arguments = [self.get_executable()]
         rom = self.game_config.get('main_file') or ''
-        if not os.path.exists(rom):
+        if not system.path_exists(rom):
             return {'error': 'FILE_NOT_FOUND', 'file': rom}
         arguments.append(rom)
         return {"command": arguments}
