@@ -35,6 +35,7 @@ LIBRETRO_CORES = [
     ('Hatari (Atari ST/STE/TT/Falcon)', 'hatari', 'Atari ST/STE/TT/Falcon'),
     ('higan accuracy(Super Nintendo)', 'higan_sfc', 'Nintendo SNES'),
     ('higan balanced(Super Nintendo)', 'higan_sfc_balanced', 'Nintendo SNES'),
+    ('Kronos (Sega Saturn)', 'kronos', 'Sega Saturn'),
     ('MAME (Arcade)', 'mame', 'Arcade'),
     ('Mednafen GBA (Game Boy Advance)', 'mednafen_gba', 'Nintendo Game Boy Advance'),
     ('Mednafen NGP (SNK Neo Geo Pocket)', 'mednafen_ngp', 'SNK Neo Geo Pocket'),
@@ -79,9 +80,11 @@ LIBRETRO_CORES = [
 def get_core_choices():
     return [(core[0], core[1]) for core in LIBRETRO_CORES]
 
+
 def get_default_config_path(path=''):
     return os.path.join(settings.RUNNER_DIR, 'retroarch', path)
 
+
 class libretro(Runner):
     human_name = "Libretro"
     description = "Multi system emulator"
@@ -129,7 +132,8 @@ class libretro(Runner):
                     return core[2]
         return ''
 
-    def get_core_path(self, core):
+    @staticmethod
+    def get_core_path(core):
         return os.path.join(settings.RUNNER_DIR,
                             'retroarch/cores/{}_libretro.so'.format(core))
 
@@ -137,14 +141,14 @@ class libretro(Runner):
         return self.game_config['core']
 
     def is_retroarch_installed(self):
-        return os.path.exists(self.get_executable())
+        return system.path_exists(self.get_executable())
 
     def is_installed(self, core=None):
         if self.game_config.get('core') and core is None:
             core = self.game_config['core']
         if not core or self.runner_config.get('runner_executable'):
             return self.is_retroarch_installed()
-        is_core_installed = os.path.exists(self.get_core_path(core))
+        is_core_installed = system.path_exists(self.get_core_path(core))
         return self.is_retroarch_installed() and is_core_installed
 
     def install(self, version=None, downloader=None, callback=None):
@@ -164,13 +168,15 @@ class libretro(Runner):
 
     def get_run_data(self):
         return {
-            'command': [self.get_executable()] + self.get_runner_parameters()
+            'command': [self.get_executable()] + self.get_runner_parameters(),
+            'env': self.get_env()
         }
 
     def get_config_file(self):
         return self.runner_config.get('config_file') or get_default_config_path('retroarch.cfg')
 
-    def get_system_directory(self, retro_config):
+    @staticmethod
+    def get_system_directory(retro_config):
         """Return the system directory used for storing BIOS and firmwares."""
         system_directory = retro_config['system_directory']
         if not system_directory or system_directory == 'default':
@@ -181,7 +187,7 @@ class libretro(Runner):
         config_file = self.get_config_file()
 
         # Create retroarch.cfg if it doesn't exist.
-        if not os.path.exists(config_file):
+        if not system.path_exists(config_file):
             f = open(config_file, 'w')
             f.write('# Lutris RetroArch Configuration')
             f.close()
@@ -210,7 +216,7 @@ class libretro(Runner):
         core = self.game_config.get('core')
         info_file = os.path.join(get_default_config_path('info'),
                                  '{}_libretro.info'.format(core))
-        if os.path.exists(info_file):
+        if system.path_exists(info_file):
             core_config = RetroConfig(info_file)
             try:
                 firmware_count = int(core_config['firmware_count'])
@@ -227,7 +233,7 @@ class libretro(Runner):
             for index in range(firmware_count):
                 firmware_filename = core_config['firmware%d_path' % index]
                 firmware_path = os.path.join(system_path, firmware_filename)
-                if os.path.exists(firmware_path):
+                if system.path_exists(firmware_path):
                     if firmware_filename in checksums:
                         checksum = system.get_md5_hash(firmware_path)
                         if checksum == checksums[firmware_filename]:
@@ -236,10 +242,9 @@ class libretro(Runner):
                             checksum_status = 'Checksum failed'
                     else:
                         checksum_status = 'No checksum info'
-                    logger.info("Firmware '{}' found ({})".format(firmware_filename,
-                                                                  checksum_status))
+                    logger.info("Firmware '%s' found (%s)", firmware_filename, checksum_status)
                 else:
-                    logger.warning("Firmware '{}' not found!".format(firmware_filename))
+                    logger.warning("Firmware '%s' not found!", firmware_filename)
 
                 # Before closing issue #431
                 # TODO check for firmware*_opt and display an error message if
@@ -280,7 +285,7 @@ class libretro(Runner):
                 'error': 'CUSTOM',
                 'text': 'No game file specified'
             }
-        if not os.path.exists(file):
+        if not system.path_exists(file):
             return {
                 'error': 'FILE_NOT_FOUND',
                 'file': file
