@@ -1,5 +1,5 @@
-import os
 from lutris.runners.runner import Runner
+from lutris.util import system
 
 
 class openmsx(Runner):
@@ -11,12 +11,12 @@ class openmsx(Runner):
             "option": "main_file",
             "type": "file",
             "label": "ROM file",
-            'help': ("The game data, commonly called a ROM image.")
+            'help': "The game data, commonly called a ROM image."
         }
     ]
 
     def play(self):
         rom = self.game_config.get('main_file') or ''
-        if not os.path.exists(rom):
+        if not system.path_exists(rom):
             return {'error': 'FILE_NOT_FOUND', 'file': rom}
         return {'command': [self.get_executable(), rom]}
