@@ -1,5 +1,5 @@
-import os
 from lutris.runners.runner import Runner
+from lutris.util import system
 
 
 class osmose(Runner):
@@ -31,7 +31,7 @@ class osmose(Runner):
         """Run Sega Master System game"""
         arguments = [self.get_executable()]
         rom = self.game_config.get('main_file') or ''
-        if not os.path.exists(rom):
+        if not system.path_exists(rom):
             return {'error': 'FILE_NOT_FOUND', 'file': rom}
         arguments.append(rom)
         if self.runner_config.get('fullscreen'):
