@@ -1,5 +1,5 @@
-import os
 from lutris.runners.runner import Runner
+from lutris.util import system
 
 
 class stella(Runner):
@@ -22,6 +22,6 @@ class stella(Runner):
 
     def play(self):
         cart = self.game_config.get('main_file') or ''
-        if not os.path.exists(cart):
+        if not system.path_exists(cart):
             return {'error': 'FILE_NOT_FOUND', 'file': cart}
         return {'command': [self.get_executable(), cart]}
