@@ -1,5 +1,5 @@
-import os
 from lutris.runners.runner import Runner
+from lutris.util import system
 
 
 class tic80(Runner):
@@ -8,7 +8,7 @@ class tic80(Runner):
     platforms = ['TIC-80']
     runner_executable = 'tic80/tic80'
     game_options = [
-    	{
+        {
             'option': 'main_file',
             'type': 'file',
             'label': 'ROM file',
@@ -47,7 +47,7 @@ class tic80(Runner):
         if self.runner_config.get('nosound'):
             arguments.append('-nosound')
         rom = self.game_config.get('main_file') or ''
-        if not os.path.exists(rom):
+        if not system.path_exists(rom):
             return {'error': 'FILE_NOT_FOUND', 'file': rom}
         arguments.append(rom)
         return {"command": arguments}
