@@ -1,5 +1,5 @@
-import os
 from lutris.runners.runner import Runner
+from lutris.util import system
 
 
 class virtualjaguar(Runner):
@@ -30,6 +30,6 @@ class virtualjaguar(Runner):
 
     def play(self):
         rom = self.game_config.get('main_file') or ''
-        if not os.path.exists(rom):
+        if not system.path_exists(rom):
             return {'error': 'FILE_NOT_FOUND', 'file': rom}
         return {'command': [self.get_executable(), rom]}
