@@ -1,6 +1,6 @@
 import os
 import shlex
-from lutris.util import display
+from lutris.util import display, system
 from lutris.runners.runner import Runner
 
 
@@ -15,13 +15,13 @@ class zdoom(Runner):
             'option': 'main_file',
             'type': 'file',
             'label': 'WAD file',
-            'help': ("The game data, commonly called a WAD file.")
+            'help': "The game data, commonly called a WAD file."
         },
         {
             'option': 'args',
             'type': 'string',
             'label': 'Arguments',
-            'help': ("Command line arguments used when launching the game.")
+            'help': "Command line arguments used when launching the game."
         },
         {
             'option': 'files',
@@ -34,14 +34,14 @@ class zdoom(Runner):
             'option': 'warp',
             'type': 'string',
             'label': 'Warp to map',
-            'help': ("Starts the game on the given map.")
+            'help': "Starts the game on the given map."
         },
         {
             'option': 'savedir',
             'type': 'directory_chooser',
             'label': 'Save path',
             'help': ("User-specified path where save files should be located.")
-        }        
+        }
     ]
     runner_options = [
         {
@@ -93,11 +93,11 @@ class zdoom(Runner):
     def get_executable(self):
         executable = super(zdoom, self).get_executable()
         executable_dir = os.path.dirname(executable)
-        if not os.path.exists(executable_dir):
+        if not system.path_exists(executable_dir):
             return executable
-        if not os.path.exists(executable):
+        if not system.path_exists(executable):
             gzdoom_executable = os.path.join(executable_dir, 'gzdoom')
-            if os.path.exists(gzdoom_executable):
+            if system.path_exists(gzdoom_executable):
                 return gzdoom_executable
         return executable
 
@@ -131,20 +131,20 @@ class zdoom(Runner):
         if config:
             command.append("-config")
             command.append(config)
-            
+
         # Append the warp arguments.
         warp = self.game_config.get('warp')
         if warp:
             command.append("-warp")
             for warparg in warp.split(' '):
                 command.append(warparg)
-    
+
         # Append directory for save games, if provided.
         savedir = self.game_config.get('savedir')
         if savedir:
             command.append("-savedir")
             command.append(savedir)
-                
+
         # Append the wad file to load, if provided.
         wad = self.game_config.get('main_file')
         if wad:
@@ -166,10 +166,10 @@ class zdoom(Runner):
             command.append("-file")
             for pwad in pwads:
                 command.append(pwad)
-        
+
         # Append additional arguments, if provided.
         args = self.game_config.get('args') or ''
         for arg in shlex.split(args):
             command.append(arg)
-        
+
         return {'command': command}
