@@ -3,6 +3,7 @@ import os
 from collections import OrderedDict
 
 from lutris import runners
+# from lutris.util.log import logger
 from lutris.util import display, system
 
 DISPLAYS = None
@@ -54,7 +55,7 @@ def get_optirun_choices():
     return choices
 
 
-system_options = [
+system_options = [  # pylint: disable=invalid-name
     {
         'option': 'game_path',
         'type': 'directory_chooser',
@@ -94,6 +95,14 @@ system_options = [
                  "performance. primusrun normally has better performance, but"
                  "optirun/virtualgl works better for more games.")
     },
+    {
+        'option': 'gamemode',
+        'type': 'bool',
+        'default': bool(system.GAMEMODE_PATH),
+        'condition': bool(system.GAMEMODE_PATH),
+        'label': 'Enable Feral gamemode',
+        'help': 'Request a set of optimisations be temporarily applied to the host OS'
+    },
     {
         'option': 'dri_prime',
         'type': 'bool',
@@ -169,6 +178,27 @@ system_options = [
         'help': ("Command line instructions to add in front of the game's "
                  "execution command.")
     },
+    {
+        'option': 'ondemand_command',
+        'type': 'file',
+        'label': 'On-demand command',
+        'advanced': True,
+        'help': ("Script to execute from the game's contextual menu")
+    },
+    {
+        'option': 'prelaunch_command',
+        'type': 'file',
+        'label': 'Pre-launch command',
+        'advanced': True,
+        'help': "Script to execute before the game starts"
+    },
+    {
+        'option': 'postexit_command',
+        'type': 'file',
+        'label': 'Post-exit command',
+        'advanced': True,
+        'help': "Script to execute when the game exits"
+    },
     {
         'option': 'include_processes',
         'type': 'string',
