@@ -1,6 +1,7 @@
 import os
 import sys
 from lutris import settings
+from lutris.util import system
 
 
 def get():
@@ -10,7 +11,7 @@ def get():
         data_path = '/usr/local/share/lutris'
     elif launch_path.startswith("/usr"):
         data_path = '/usr/share/lutris'
-    elif os.path.exists(os.path.normpath(os.path.join(sys.path[0], 'share'))):
+    elif system.path_exists(os.path.normpath(os.path.join(sys.path[0], 'share'))):
         data_path = os.path.normpath(os.path.join(sys.path[0], 'share/lutris'))
     else:
         import lutris
@@ -18,7 +19,7 @@ def get():
         data_path = os.path.join(
             os.path.dirname(os.path.dirname(lutris_module)), 'share/lutris'
         )
-    if not os.path.exists(data_path):
+    if not system.path_exists(data_path):
         raise IOError("data_path can't be found at : %s" % data_path)
     return data_path
 
