@@ -10,9 +10,9 @@ from lutris.settings import SITE_URL, VERSION, PROJECT
 from lutris.util.log import logger
 
 
-class Request(object):
+class Request:
     def __init__(self, url, timeout=30, stop_request=None,
-                 thread_queue=None, headers={}):
+                 thread_queue=None, headers=None):
 
         if not url:
             raise ValueError('An URL is required!')
@@ -33,6 +33,8 @@ class Request(object):
         self.headers = {
             'User-Agent': self.user_agent
         }
+        if headers is None:
+            headers = {}
         if not isinstance(headers, dict):
             raise TypeError('HTTP headers needs to be a dict ({})'.format(headers))
         self.headers.update(headers)
@@ -48,10 +50,10 @@ class Request(object):
         req = urllib.request.Request(url=self.url, data=data, headers=self.headers)
         try:
             request = urllib.request.urlopen(req, timeout=self.timeout)
-        except (urllib.error.HTTPError, CertificateError) as e:
-            logger.error("Unavailable url (%s): %s", self.url, e)
-        except (socket.timeout, urllib.error.URLError) as e:
-            logger.error("Unable to connect to server (%s): %s", self.url, e)
+        except (urllib.error.HTTPError, CertificateError) as error:
+            logger.error("Unavailable url (%s): %s", self.url, error)
+        except (socket.timeout, urllib.error.URLError) as error:
+            logger.error("Unable to connect to server (%s): %s", self.url, error)
         else:
             # Response code is available with getcode but should 200 if there
             # is no exception
@@ -70,7 +72,7 @@ class Request(object):
                     return self
                 try:
                     chunk = request.read(self.buffer_size)
-                except socket.timeout as e:
+                except socket.timeout:
                     logger.error("Request timed out")
                     self.content = ''
                     return self
@@ -100,8 +102,10 @@ class Request(object):
     def json(self):
         if self.content:
             return json.loads(self.text)
+        return None
 
     @property
     def text(self):
         if self.content:
             return self.content.decode()
+        return None
