@@ -1,4 +1,4 @@
-import os
+from lutris.util import system
 
 
 def check_joysticks():
@@ -7,7 +7,7 @@ def check_joysticks():
     joysticks = []
     for device_number in range(0, 8):
         device_name = "/dev/input/js%d" % device_number
-        if os.path.exists(device_name):
+        if system.path_exists(device_name):
             number_joysticks = number_joysticks + 1
             joysticks.append(device_name)
     return joysticks
