@@ -1,6 +1,5 @@
+"""Module for handling game media (banners and icons)"""
 import os
-import re
-import shutil
 import concurrent.futures
 from urllib.parse import urlparse, parse_qsl
 from gi.repository import GLib
@@ -9,6 +8,7 @@ from lutris import settings
 from lutris import api
 from lutris.util.log import logger
 from lutris.util.http import Request
+from lutris.util import system
 
 BANNER = "banner"
 ICON = "icon"
@@ -17,17 +17,19 @@ ICON = "icon"
 def get_icon_path(game, icon_type):
     if icon_type == BANNER:
         return os.path.join(settings.BANNER_PATH, "%s.jpg" % game)
-    if icon_type == ICON:
+    elif icon_type == ICON:
         return os.path.join(settings.ICON_PATH, "lutris_%s.png" % game)
+    return None
 
 
 def has_icon(game, icon_type):
     if icon_type == BANNER:
         icon_path = get_icon_path(game, BANNER)
-        return os.path.exists(icon_path)
+        return system.path_exists(icon_path)
     elif icon_type == ICON:
         icon_path = get_icon_path(game, ICON)
-        return os.path.exists(icon_path)
+        return system.path_exists(icon_path)
+    return False
 
 
 def fetch_icons(game_slugs, callback=None):
@@ -39,9 +41,8 @@ def fetch_icons(game_slugs, callback=None):
     if not missing_media_slugs:
         logger.debug("No icon are missing")
         return
-    logger.debug("Requesting missing icons from API")
+    logger.debug("Requesting missing icons from API for %d games", len(missing_media_slugs))
     results = api.get_games(game_slugs=missing_media_slugs)
-    logger.debug("Got %d icons", len(results))
 
     new_icon = False
     banner_downloads = []
@@ -64,7 +65,9 @@ def fetch_icons(game_slugs, callback=None):
 
     updated_slugs = list(set(updated_slugs))  # Deduplicate slugs
     downloads = banner_downloads + icon_downloads
-    logger.debug("Downloading %d files", len(downloads))
+    if downloads:
+        logger.debug("Downloading %d files", len(downloads))
+
     with concurrent.futures.ThreadPoolExecutor(max_workers=8) as executor:
         futs = [executor.submit(download_media, url, dest_path)
                 for url, dest_path in downloads]
@@ -76,18 +79,19 @@ def fetch_icons(game_slugs, callback=None):
     if updated_slugs and callback:
         callback(updated_slugs)
 
+
 def udpate_desktop_icons():
     # Update Icon for GTK+ desktop manager
-    gtk_update_icon_cache = shutil.which("gtk-update-icon-cache")
-    if (gtk_update_icon_cache):
-        os.system("gtk-update-icon-cache -tf %s"
-        % os.path.join(GLib.get_user_data_dir(), 'icons', 'hicolor'))
+    gtk_update_icon_cache = system.find_executable("gtk-update-icon-cache")
+    if gtk_update_icon_cache:
+        os.system("gtk-update-icon-cache -tf %s" % os.path.join(GLib.get_user_data_dir(), 'icons', 'hicolor'))
 
     # Other desktop manager cache command must be added here when needed
 
+
 def download_media(url, dest, overwrite=False):
     logger.debug("Downloading %s to %s", url, dest)
-    if os.path.exists(dest):
+    if system.path_exists(dest):
         if overwrite:
             os.remove(dest)
         else:
