@@ -3,6 +3,7 @@ import re
 from collections import OrderedDict
 from datetime import datetime
 from lutris.util.log import logger
+from lutris.util import system
 
 (
     REG_NONE,
@@ -64,7 +65,7 @@ class WindowsFileTime:
         return datetime.fromtimestamp(self.to_unix_timestamp())
 
 
-class WineRegistry(object):
+class WineRegistry:
     version_header = "WINE REGISTRY Version "
     relative_to_header = ";; All keys relative to "
 
@@ -75,7 +76,7 @@ class WineRegistry(object):
         self.keys = OrderedDict()
         self.reg_filename = reg_filename
         if reg_filename:
-            if not os.path.exists(reg_filename):
+            if not system.path_exists(reg_filename):
                 logger.error("Unexisting registry %s", reg_filename)
             self.parse_reg_file(reg_filename)
 
@@ -85,9 +86,10 @@ class WineRegistry(object):
         if self.reg_filename:
             return os.path.dirname(self.reg_filename)
 
-    def get_raw_registry(self, reg_filename):
+    @staticmethod
+    def get_raw_registry(reg_filename):
         """Return an array of the unprocessed contents of a registry file"""
-        if not os.path.exists(reg_filename):
+        if not system.path_exists(reg_filename):
             return []
         with open(reg_filename, 'r') as reg_file:
             registry_content = reg_file.readlines()
@@ -172,13 +174,12 @@ class WineRegistry(object):
                 continue
             key.subkeys.pop(subkey)
 
-
     def get_unix_path(self, windows_path):
         windows_path = windows_path.replace('\\\\', '/')
         if not self.prefix_path:
             return
         drives_path = os.path.join(self.prefix_path, "dosdevices")
-        if not os.path.exists(drives_path):
+        if not system.path_exists(drives_path):
             return
         letter, relpath = windows_path.split(':', 1)
         relpath = relpath.strip('/')
@@ -194,7 +195,7 @@ class WineRegistry(object):
         return os.path.join(drive_path, relpath)
 
 
-class WineRegistryKey(object):
+class WineRegistryKey:
     def __init__(self, key_def=None, path=None):
 
         self.subkeys = OrderedDict()
@@ -206,7 +207,6 @@ class WineRegistryKey(object):
             self.name = path
             self.raw_name = "[{}]".format(path.replace('/', '\\\\'))
             self.raw_timestamp = ' '.join(str(timestamp).split('.'))
-            key_def = "{} {}".format(self.raw_name, self.raw_timestamp)
 
             windows_timestamp = WindowsFileTime.from_unix_timestamp(timestamp)
             self.metas["time"] = windows_timestamp.to_hex()
@@ -299,7 +299,7 @@ class WineRegistryKey(object):
 
     def get_subkey(self, name):
         if name not in self.subkeys:
-            return
+            return None
         value = self.subkeys[name]
         if value.startswith("\"") and value.endswith("\""):
             return value[1:-1]
